@@ -185,6 +185,12 @@ PALETTES = {
         '#6060E0E06F6F:#D6D698982727:#7878D8D8D8D8:#CDCD7C7C5353:#5858D5D59898:'
         '#FFFFF1F1E8E8:#808079797373:#212121211C1C'
     ),
+    'Elementary Loki': (
+        '#070736364242:#DCDC32322F2F:#858599990000:#B5B589890000:#26268B8BD2D2:'
+        '#ECEC00004848:#2A2AA1A19898:#9494A3A3A5A5:#58586E6E7575:#CBCB4B4B1616:'
+        '#858599990000:#B5B589890000:#26268B8BD2D2:#D3D336368282:#2A2AA1A19898:'
+        '#EEEEEEEEEEEE:#9494A3A3A5A5:#25252E2E3232'
+    ),
     'Espresso Libre': (
         '#000000000000:#CCCC00000000:#1A1A92921C1C:#EFEFE4E43A3A:#00006666FFFF:'
         '#C5C565656B6B:#050598989A9A:#D3D3D7D7CFCF:#545457575353:#EFEF28282828:'
